optTune
=======

The optimization tuning (optTune) Python package contains various tuning algorithms designed for tuning an optimization algorithm under multiple objective function evaluation budgets.
